require 'spec_helper'
require 'presto/transformation/validator'

describe Presto::Transformation::Validator do
	let(:w) { 100 }
	let(:h) { 200 }
	let(:fit) { 'clip' }
	let(:bg) { '#fffddd' }
	let(:fm){ 'jpg' }
	let(:q){ 92 }
	let(:transformation) { stub(:w => w, :h => h, :fit => fit, :bg => bg, :fm => fm, :q => q) }
	let(:validator){ Presto::Transformation::Validator.new(transformation) }

	let(:errors) { validator.valid?; validator.errors }

	context 'when valid' do
		it { errors.must_be_empty }
	end

	context 'when w is nil' do
		let(:w) { nil }
		it { errors.must_be_empty }
	end

	context "when w is greater than max w" do
		let(:w) { Presto.configuration.max_width + 1 }
		it { errors[:w].must_include "must be less than or equal to 2000" }
	end

	context "when w is greater than max w" do
		let(:w) { Presto.configuration.min_width - 1 }
		it { errors[:w].must_include "must be greater than or equal to 1" }
	end

	context 'when h is nil' do
		let(:h) { nil }
		it { errors.must_be_empty }
	end

	context 'when h is greater than max h' do
		let(:h) { Presto.configuration.max_width + 1 }
		it { errors[:h].must_include "must be less than or equal to 2000" }
	end

	context 'when h is greater than max h' do
		let(:h) { Presto.configuration.min_width - 1 }
		it { errors[:h].must_include "must be greater than or equal to 1" }
	end

	context 'when fit is nil' do
		let(:fit) { nil }
		it { errors[:fit].must_include "is not present" }
	end

	context 'when fit is invalid' do
		let(:fit) { 'blah' }
		it { errors[:fit].must_include "is not in set: [\"clip\", \"crop\", \"scale\", \"fill\", \"max\"]" }
	end

	context 'when bg is wrong format' do
		let(:bg) { 'fhff' }
		it { errors[:bg].must_include "is not valid" }
	end

	context 'when fm is invalid' do
		let(:fm) { 'tif' }
		it { errors[:fm].must_include "is not in set: [\"jpg\", \"png\"]" }
	end

	context 'when q is nil' do
		let(:q) { nil }
		it { errors[:q].must_be_nil }
	end

	context "when q is greater than max q" do
		let(:q) { ::Presto::Transformation::Validator::QUALITY_MAX + 1 }
		it { errors[:q].must_include "must be less than or equal to 100" }
	end

	context "when q is less than min q" do
		let(:q) { ::Presto::Transformation::Validator::QUALITY_MIN - 1 }
		it { errors[:q].must_include "must be greater than or equal to 1" }
	end
end